@@ -38,7 +38,7 @@ Contributors:
 #endif
 
 #ifdef WITH_CJSON
-#  include <cJSON.h>
+#  include <cjson/cJSON.h>
 #endif
 
 #ifdef __APPLE__
