@@ -2,14 +2,16 @@
 Copyright (c) 2009-2020 Roger Light <roger@atchoo.org>
 
 All rights reserved. This program and the accompanying materials
-are made available under the terms of the Eclipse Public License v1.0
+are made available under the terms of the Eclipse Public License 2.0
 and Eclipse Distribution License v1.0 which accompany this distribution.
 
 The Eclipse Public License is available at
-   http://www.eclipse.org/legal/epl-v10.html
+   https://www.eclipse.org/legal/epl-2.0/
 and the Eclipse Distribution License is available at
   http://www.eclipse.org/org/documents/edl-v10.php.
 
+SPDX-License-Identifier: EPL-2.0 OR EDL-1.0
+
 Contributors:
    Roger Light - initial implementation and documentation.
 */
@@ -38,14 +40,12 @@ int handle__publish(struct mosquitto *mosq)
 	struct mosquitto_message_all *message;
 	int rc = 0;
 	uint16_t mid;
-	int slen;
+	uint16_t slen;
 	mosquitto_property *properties = NULL;
-	int state;
 
 	assert(mosq);
 
-	state = mosquitto__get_state(mosq);
-	if(state != mosq_cs_active){
+	if(mosquitto__get_state(mosq) != mosq_cs_active){
 		return MOSQ_ERR_PROTOCOL;
 	}
 
@@ -94,15 +94,15 @@ int handle__publish(struct mosquitto *mosq)
 		if(rc) return rc;
 	}
 
-	message->msg.payloadlen = mosq->in_packet.remaining_length - mosq->in_packet.pos;
+	message->msg.payloadlen = (int)(mosq->in_packet.remaining_length - mosq->in_packet.pos);
 	if(message->msg.payloadlen){
-		message->msg.payload = mosquitto__calloc(message->msg.payloadlen+1, sizeof(uint8_t));
+		message->msg.payload = mosquitto__calloc((size_t)message->msg.payloadlen+1, sizeof(uint8_t));
 		if(!message->msg.payload){
 			message__cleanup(&message);
 			mosquitto_property_free_all(&properties);
 			return MOSQ_ERR_NOMEM;
 		}
-		rc = packet__read_bytes(&mosq->in_packet, message->msg.payload, message->msg.payloadlen);
+		rc = packet__read_bytes(&mosq->in_packet, message->msg.payload, (uint32_t)message->msg.payloadlen);
 		if(rc){
 			message__cleanup(&message);
 			mosquitto_property_free_all(&properties);
@@ -135,7 +135,7 @@ int handle__publish(struct mosquitto *mosq)
 			return MOSQ_ERR_SUCCESS;
 		case 1:
 			util__decrement_receive_quota(mosq);
-			rc = send__puback(mosq, message->msg.mid, 0);
+			rc = send__puback(mosq, mid, 0, NULL);
 			pthread_mutex_lock(&mosq->callback_mutex);
 			if(mosq->on_message){
 				mosq->in_callback = true;
@@ -154,7 +154,7 @@ int handle__publish(struct mosquitto *mosq)
 		case 2:
 			message->properties = properties;
 			util__decrement_receive_quota(mosq);
-			rc = send__pubrec(mosq, message->msg.mid, 0);
+			rc = send__pubrec(mosq, mid, 0, NULL);
 			pthread_mutex_lock(&mosq->msgs_in.mutex);
 			message->state = mosq_ms_wait_for_pubrel;
 			message__queue(mosq, message, mosq_md_in);
