@@ -2,14 +2,16 @@
 Copyright (c) 2009-2020 Roger Light <roger@atchoo.org>
 
 All rights reserved. This program and the accompanying materials
-are made available under the terms of the Eclipse Public License v1.0
+are made available under the terms of the Eclipse Public License 2.0
 and Eclipse Distribution License v1.0 which accompany this distribution.
 
 The Eclipse Public License is available at
-   http://www.eclipse.org/legal/epl-v10.html
+   https://www.eclipse.org/legal/epl-2.0/
 and the Eclipse Distribution License is available at
   http://www.eclipse.org/org/documents/edl-v10.php.
 
+SPDX-License-Identifier: EPL-2.0 OR EDL-1.0
+
 Contributors:
    Roger Light - initial implementation and documentation.
 */
@@ -29,7 +31,6 @@ int send__suback(struct mosquitto *context, uint16_t mid, uint32_t payloadlen, c
 	struct mosquitto__packet *packet = NULL;
 	int rc;
 	mosquitto_property *properties = NULL;
-	int proplen, varbytes;
 
 	log__printf(NULL, MOSQ_LOG_DEBUG, "Sending SUBACK to %s", context->id);
 
@@ -39,9 +40,7 @@ int send__suback(struct mosquitto *context, uint16_t mid, uint32_t payloadlen, c
 	packet->command = CMD_SUBACK;
 	packet->remaining_length = 2+payloadlen;
 	if(context->protocol == mosq_p_mqtt5){
-		proplen = property__get_length_all(properties);
-		varbytes = packet__varint_bytes(proplen);
-		packet->remaining_length += proplen + varbytes;
+		packet->remaining_length += property__get_remaining_length(properties);
 	}
 	rc = packet__alloc(packet);
 	if(rc){
