@@ -16,6 +16,8 @@ try:
     sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=port)
     sock.close()
     rc = 0
+except mosq_test.TestError:
+    pass
 finally:
     broker.terminate()
     broker.wait()
