@@ -16,6 +16,7 @@ uint64_t last_retained;
 char *last_sub = NULL;
 int last_qos;
 
+struct mosquitto_db db;
 
 /* read entire file into memory */
 static int file_read(const char *filename, uint8_t **data, size_t *len)
@@ -27,7 +28,7 @@ static int file_read(const char *filename, uint8_t **data, size_t *len)
 	if(!fptr) return 1;
 
 	fseek(fptr, 0, SEEK_END);
-	*len = ftell(fptr);
+	*len = (size_t)ftell(fptr);
 	*data = malloc(*len);
 	if(!(*data)){
 		fclose(fptr);
@@ -73,26 +74,25 @@ static int file_diff(const char *one, const char *two)
 
 static void TEST_persistence_disabled(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	int rc;
 
 	memset(&db, 0, sizeof(struct mosquitto_db));
 	memset(&config, 0, sizeof(struct mosquitto__config));
 	db.config = &config;
+	config.persistence = true;
 
-	rc = persist__backup(&db, false);
+	rc = persist__backup(false);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_INVAL);
 
 	config.persistence_filepath = "disabled.db";
-	rc = persist__backup(&db, false);
+	rc = persist__backup(false);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 }
 
 
 static void TEST_empty_file(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	int rc;
 
@@ -103,7 +103,7 @@ static void TEST_empty_file(void)
 	config.persistence = true;
 
 	config.persistence_filepath = "empty.db";
-	rc = persist__backup(&db, false);
+	rc = persist__backup(false);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_write/empty.test-db", "empty.db"));
 	unlink("empty.db");
@@ -112,7 +112,6 @@ static void TEST_empty_file(void)
 
 static void TEST_v6_config_ok(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	int rc;
 
@@ -122,11 +121,11 @@ static void TEST_v6_config_ok(void)
 
 	config.persistence = true;
 	config.persistence_filepath = "files/persist_read/v6-cfg.test-db";
-	rc = persist__restore(&db);
+	rc = persist__restore();
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	config.persistence_filepath = "v6-cfg.db";
-	rc = persist__backup(&db, true);
+	rc = persist__backup(true);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_read/v6-cfg.test-db", "v6-cfg.db"));
@@ -136,7 +135,6 @@ static void TEST_v6_config_ok(void)
 
 static void TEST_v6_message_store_no_ref(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	int rc;
 
@@ -146,11 +144,11 @@ static void TEST_v6_message_store_no_ref(void)
 
 	config.persistence = true;
 	config.persistence_filepath = "files/persist_read/v6-message-store.test-db";
-	rc = persist__restore(&db);
+	rc = persist__restore();
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	config.persistence_filepath = "v6-message-store-no-ref.db";
-	rc = persist__backup(&db, true);
+	rc = persist__backup(true);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_write/v6-message-store-no-ref.test-db", "v6-message-store-no-ref.db"));
@@ -160,7 +158,6 @@ static void TEST_v6_message_store_no_ref(void)
 
 static void TEST_v6_message_store_props(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	struct mosquitto__listener listener;
 	int rc;
@@ -176,11 +173,11 @@ static void TEST_v6_message_store_props(void)
 
 	config.persistence = true;
 	config.persistence_filepath = "files/persist_read/v6-message-store-props.test-db";
-	rc = persist__restore(&db);
+	rc = persist__restore();
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	config.persistence_filepath = "v6-message-store-props.db";
-	rc = persist__backup(&db, true);
+	rc = persist__backup(true);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_read/v6-message-store-props.test-db", "v6-message-store-props.db"));
@@ -190,7 +187,6 @@ static void TEST_v6_message_store_props(void)
 
 static void TEST_v6_client(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	struct mosquitto__listener listener;
 	int rc;
@@ -206,11 +202,11 @@ static void TEST_v6_client(void)
 
 	config.persistence = true;
 	config.persistence_filepath = "files/persist_read/v6-client.test-db";
-	rc = persist__restore(&db);
+	rc = persist__restore();
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	config.persistence_filepath = "v6-client.db";
-	rc = persist__backup(&db, true);
+	rc = persist__backup(true);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_read/v6-client.test-db", "v6-client.db"));
@@ -220,7 +216,6 @@ static void TEST_v6_client(void)
 
 static void TEST_v6_client_message(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	struct mosquitto__listener listener;
 	int rc;
@@ -236,11 +231,11 @@ static void TEST_v6_client_message(void)
 
 	config.persistence = true;
 	config.persistence_filepath = "files/persist_read/v6-client-message.test-db";
-	rc = persist__restore(&db);
+	rc = persist__restore();
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	config.persistence_filepath = "v6-client-message.db";
-	rc = persist__backup(&db, true);
+	rc = persist__backup(true);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_read/v6-client-message.test-db", "v6-client-message.db"));
@@ -250,7 +245,6 @@ static void TEST_v6_client_message(void)
 
 static void TEST_v6_client_message_props(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	struct mosquitto__listener listener;
 	int rc;
@@ -266,7 +260,7 @@ static void TEST_v6_client_message_props(void)
 
 	config.persistence = true;
 	config.persistence_filepath = "files/persist_read/v6-client-message-props.test-db";
-	rc = persist__restore(&db);
+	rc = persist__restore();
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_PTR_NOT_NULL(db.msg_store);
@@ -278,7 +272,7 @@ static void TEST_v6_client_message_props(void)
 	}
 
 	config.persistence_filepath = "v6-client-message-props.db";
-	rc = persist__backup(&db, true);
+	rc = persist__backup(true);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_read/v6-client-message-props.test-db", "v6-client-message-props.db"));
@@ -288,7 +282,6 @@ static void TEST_v6_client_message_props(void)
 
 static void TEST_v6_sub(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	struct mosquitto__listener listener;
 	int rc;
@@ -302,15 +295,15 @@ static void TEST_v6_sub(void)
 	config.listeners = &listener;
 	config.listener_count = 1;
 
-	db__open(&config, &db);
+	db__open(&config);
 
 	config.persistence = true;
 	config.persistence_filepath = "files/persist_read/v6-sub.test-db";
-	rc = persist__restore(&db);
+	rc = persist__restore();
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	config.persistence_filepath = "v6-sub.db";
-	rc = persist__backup(&db, true);
+	rc = persist__backup(true);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_read/v6-sub.test-db", "v6-sub.db"));
@@ -322,7 +315,6 @@ static void TEST_v6_sub(void)
 NOT WORKING
 static void TEST_v5_full(void)
 {
-	struct mosquitto_db db;
 	struct mosquitto__config config;
 	int rc;
 
@@ -330,15 +322,15 @@ static void TEST_v5_full(void)
 	memset(&config, 0, sizeof(struct mosquitto__config));
 	db.config = &config;
 
-	db__open(&config, &db);
+	db__open(&config);
 
 	config.persistence = true;
 	config.persistence_filepath = "files/persist_write/v5-full.test-db";
-	rc = persist__restore(&db);
+	rc = persist__restore();
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	config.persistence_filepath = "v5-full.db";
-	rc = persist__backup(&db, true);
+	rc = persist__backup(true);
 	CU_ASSERT_EQUAL(rc, MOSQ_ERR_SUCCESS);
 
 	CU_ASSERT_EQUAL(0, file_diff("files/persist_write/v5-full.test-db", "v5-full.db"));
